Enums
Functions
- broken_
pipe - Convert an mpsc send error (or any displayable error) into a
ClientError::Io(BrokenPipe). This is the standard pattern when the daemon connection drops and we need to propagate the error throughclient_tx.send(...).map_err(broken_pipe)?.